@@ -4,15 +4,10 @@ from trava.ext.boosting_eval.boosting_logic import CommonBoostingEvalLogic
 
 
 class CatBoostEvalLogic(CommonBoostingEvalLogic):
-    def __init__(self,
-                 needs_plot: bool,
-                 eval_metric: str = None,
-                 early_stopping_rounds: Optional[int] = 10):
+    def __init__(self, needs_plot: bool, eval_metric: str = None, early_stopping_rounds: Optional[int] = 10):
         assert not eval_metric, "Initialize your model with the eval metric instead"
 
-        super().__init__(needs_plot=needs_plot,
-                         eval_metric=eval_metric,
-                         early_stopping_rounds=early_stopping_rounds)
+        super().__init__(needs_plot=needs_plot, eval_metric=eval_metric, early_stopping_rounds=early_stopping_rounds)
 
     def _best_iteration(self, model) -> int:
         return model.get_best_iteration()
@@ -24,10 +19,10 @@ class CatBoostEvalLogic(CommonBoostingEvalLogic):
         if self._n_eval_sets(model=model) == 1:
             return None
 
-        return 'learn'
+        return "learn"
 
     def _eval_metrics_key(self, model) -> str:
-        return 'validation'
+        return "validation"
 
     @property
     def _user_train_in_eval(self) -> bool:
